@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
-from hagworm.frame.stress_tests import Launcher, Runner, TaskInterface
 import os
 import sys
 
 os.chdir(os.path.dirname(__file__))
 sys.path.insert(0, os.path.abspath(r'../'))
 
+from hagworm.frame.stress_tests import Launcher, Runner, TaskInterface
+
 
 class Task(TaskInterface):
 
@@ -26,4 +27,4 @@ class Task(TaskInterface):
 
 if __name__ == r'__main__':
 
-    Launcher(process_number=2).run(Runner(Task).run, 8, 32)
+    Launcher(subprocess=2).run(Runner(Task), 8, 32)
