@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 
-__version__ = r'3.9.17'
+__version__ = r'4.1.0'
 
-package_slogan = r'''
+hagworm_label = f'Hagworm/{__version__}'
+
+hagworm_slogan = r'''
  __  __   ______   ______   __     __   ______   ______   __    __
 /\ \_\ \ /\  __ \ /\  ___\ /\ \  _ \ \ /\  __ \ /\  == \ /\ "-./  \
 \ \  __ \\ \  __ \\ \ \__ \\ \ \/ ".\ \\ \ \/\ \\ \  __< \ \ \-./\ \
