@@ -45,6 +45,15 @@ class RedisPool:
 
         return self
 
+    async def close(self):
+
+        if self._pool is not None:
+
+            self._pool.close()
+            await self._pool.wait_closed()
+
+            self._pool = None
+
     def get_client(self):
 
         client = None
@@ -74,6 +83,12 @@ class RedisDelegate:
 
         self._redis_pool = await RedisPool(*args, **kwargs)
 
+    async def async_close_redis(self):
+
+        if self._redis_pool is not None:
+            await self._redis_pool.close()
+            self._redis_pool = None
+
     async def cache_health(self):
 
         result = False
@@ -142,7 +157,13 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
             if (self._pool.maxsize - self._pool.size + self._pool.freesize) < REDIS_POOL_WATER_LEVEL_WARNING_LINE:
                 Utils.log.warning(
-                    f'Redis connection pool not enough: {self._pool.freesize}({self._pool.size}/{self._pool.maxsize})'
+                    f'Redis connection pool not enough: '
+                    f'{self._pool.freesize}({self._pool.size}/{self._pool.maxsize})'
+                )
+            else:
+                Utils.log.debug(
+                    f'Redis connection pool info: '
+                    f'{self._pool.freesize}({self._pool.size}/{self._pool.maxsize})'
                 )
 
             self._pool_or_conn = await self._pool.acquire()
