@@ -13,7 +13,7 @@ from sqlalchemy.sql.dml import Insert, Update, Delete
 
 from motor.motor_asyncio import AsyncIOMotorClient
 
-from hagworm.extend.error import MySQLReadOnlyError
+from hagworm.extend.error import MySQLReadOnlyError, MySQLClientDestroyed
 
 from .base import Utils, WeakContextVar, AsyncContextManager, AsyncCirculator
 
@@ -93,6 +93,12 @@ class MongoPool:
                 f'Mongo connection pool reset {address}: {len(server.pool.sockets)}/{self._pool.max_pool_size}'
             )
 
+    def close(self):
+
+        if self._pool is not None:
+            self._pool.close()
+            self._pool = None
+
     def get_database(self, db_name):
 
         self._echo_pool_info()
@@ -135,6 +141,10 @@ class MongoDelegate:
 
         self._mongo_pool.reset()
 
+    def close_mongo_pool(self):
+
+        self._mongo_pool.close()
+
     def get_mongo_database(self, db_name):
 
         return self._mongo_pool.get_database(db_name)
@@ -236,6 +246,15 @@ class MySQLPool:
 
         return self
 
+    async def close(self):
+
+        if self._pool is not None:
+
+            self._pool.close()
+            await self._pool.wait_closed()
+
+            self._pool = None
+
     def _echo_pool_info(self):
 
         global MYSQL_POLL_WATER_LEVEL_WARNING_LINE
@@ -342,6 +361,14 @@ class MySQLDelegate:
 
         self._mysql_ro_pool = await MySQLPool(*args, **kwargs)
 
+    async def async_close_mysql(self):
+
+        if self._mysql_rw_pool is not None:
+            await self._mysql_rw_pool.close()
+
+        if self._mysql_ro_pool is not None:
+            await self._mysql_ro_pool.close()
+
     async def mysql_health(self):
 
         result = await self._mysql_rw_pool.health() if self._mysql_rw_pool else True
@@ -463,14 +490,14 @@ class _ClientBase:
 
         raise NotImplementedError()
 
-    async def select(self, clause):
+    async def select(self, query, *multiparams, **params):
 
         result = []
 
-        if not isinstance(clause, Select):
+        if not isinstance(query, Select):
             raise TypeError(r'Not sqlalchemy.sql.selectable.Select object')
 
-        proxy = await self.execute(clause)
+        proxy = await self.execute(query, *multiparams, **params)
 
         if proxy is not None:
 
@@ -484,14 +511,14 @@ class _ClientBase:
 
         return result
 
-    async def find(self, clause):
+    async def find(self, query, *multiparams, **params):
 
         result = None
 
-        if not isinstance(clause, Select):
+        if not isinstance(query, Select):
             raise TypeError(r'Not sqlalchemy.sql.selectable.Select object')
 
-        proxy = await self.execute(clause)
+        proxy = await self.execute(query, *multiparams, **params)
 
         if proxy is not None:
 
@@ -505,17 +532,17 @@ class _ClientBase:
 
         return result
 
-    async def insert(self, clause):
+    async def insert(self, query, *multiparams, **params):
 
         result = 0
 
         if self._readonly:
             raise MySQLReadOnlyError()
 
-        if not isinstance(clause, Insert):
+        if not isinstance(query, Insert):
             raise TypeError(r'Not sqlalchemy.sql.dml.Insert object')
 
-        proxy = await self.execute(clause)
+        proxy = await self.execute(query, *multiparams, **params)
 
         if proxy is not None:
 
@@ -526,17 +553,17 @@ class _ClientBase:
 
         return result
 
-    async def update(self, clause):
+    async def update(self, query, *multiparams, **params):
 
         result = 0
 
         if self._readonly:
             raise MySQLReadOnlyError()
 
-        if not isinstance(clause, Update):
+        if not isinstance(query, Update):
             raise TypeError(r'Not sqlalchemy.sql.dml.Update object')
 
-        proxy = await self.execute(clause)
+        proxy = await self.execute(query, *multiparams, **params)
 
         if proxy is not None:
 
@@ -547,17 +574,17 @@ class _ClientBase:
 
         return result
 
-    async def delete(self, clause):
+    async def delete(self, query, *multiparams, **params):
 
         result = 0
 
         if self._readonly:
             raise MySQLReadOnlyError()
 
-        if not isinstance(clause, Delete):
+        if not isinstance(query, Delete):
             raise TypeError(r'Not sqlalchemy.sql.dml.Delete object')
 
-        proxy = await self.execute(clause)
+        proxy = await self.execute(query, *multiparams, **params)
 
         if proxy is not None:
 
@@ -592,7 +619,10 @@ class DBClient(_ClientBase, AsyncContextManager):
 
     async def _get_conn(self):
 
-        if self._conn is None and self._pool:
+        if self._pool is None:
+            raise MySQLClientDestroyed()
+
+        if self._conn is None:
             self._conn = await self._pool.get_sa_conn()
 
         return self._conn
@@ -620,7 +650,7 @@ class DBClient(_ClientBase, AsyncContextManager):
 
             await self._close_conn()
 
-    async def execute(self, clause):
+    async def execute(self, query, *multiparams, **params):
 
         global MYSQL_ERROR_RETRY_COUNT
 
@@ -634,7 +664,7 @@ class DBClient(_ClientBase, AsyncContextManager):
 
                     conn = await self._get_conn()
 
-                    result = await conn.execute(clause)
+                    result = await conn.execute(query, *multiparams, **params)
 
                 except (Warning, DataError, IntegrityError, ProgrammingError) as err:
 
@@ -673,12 +703,25 @@ class DBTransaction(DBClient):
 
     async def _get_conn(self):
 
-        if self._conn is None and self._pool:
-            self._conn = await self._pool.get_sa_conn()
+        if self._conn is None:
+            self._conn = await super()._get_conn()
             self._trx = await self._conn.begin()
 
         return self._conn
 
+    async def _close_conn(self, discard=False):
+
+        await super()._close_conn(discard)
+
+        if self._trx is not None:
+
+            if self._trx.is_active:
+                self._trx.close()
+
+            self._trx = None
+
+        self._pool = None
+
     async def _context_release(self):
 
         await self.rollback()
@@ -687,7 +730,7 @@ class DBTransaction(DBClient):
 
         await self.rollback()
 
-    async def execute(self, clause):
+    async def execute(self, query, *multiparams, **params):
 
         result = None
 
@@ -700,7 +743,7 @@ class DBTransaction(DBClient):
 
                 conn = await self._get_conn()
 
-                result = await conn.execute(clause)
+                result = await conn.execute(query, *multiparams, **params)
 
             except Exception as err:
 
@@ -715,9 +758,7 @@ class DBTransaction(DBClient):
         async with self._lock:
 
             if self._trx:
-                _trx, self._trx = self._trx, None
-                await _trx.commit()
-                await _trx.close()
+                await self._trx.commit()
 
             await self._close_conn()
 
@@ -726,8 +767,6 @@ class DBTransaction(DBClient):
         async with self._lock:
 
             if self._trx:
-                _trx, self._trx = self._trx, None
-                await _trx.rollback()
-                await _trx.close()
+                await self._trx.rollback()
 
             await self._close_conn()
