@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from hagworm.extend.base import Utils, StackCache
+from hagworm.extend.base import Utils
+from hagworm.extend.cache import StackCache
 
 from hagworm.extend.asyncio.net import HTTPClientPool
 from hagworm.extend.asyncio.future import ThreadPool
