@@ -2,7 +2,6 @@
 
 import os
 import ssl
-import json
 import aiohttp
 
 from enum import Enum
@@ -25,24 +24,27 @@ class STATE(Enum):
 DEFAULT_TIMEOUT = aiohttp.client.ClientTimeout(total=60, connect=10, sock_read=60, sock_connect=10)
 DOWNLOAD_TIMEOUT = aiohttp.client.ClientTimeout(total=600, connect=10, sock_read=600, sock_connect=10)
 
-_CA_FILE = os.path.join(
+CACERT_FILE = os.path.join(
     os.path.split(os.path.abspath(__file__))[0],
     r'../../static/cacert.pem'
 )
 
 
-def _json_decoder(val, *args, **kwargs):
+class _AsyncCirculator(AsyncCirculatorForSecond):
+
+    async def _sleep(self):
+
+        await Utils.sleep(self._current)
+
+
+def _json_decoder(val, **kwargs):
 
     try:
-        return json.loads(val, *args, **kwargs)
+        return Utils.json_decode(val, **kwargs)
     except Exception as err:
         Utils.log.error(f'http client json decode error: {err} => {val}')
 
 
-def create_default_context():
-    return ssl.create_default_context(cafile=_CA_FILE)
-
-
 class Result(dict):
 
     def __init__(self, status, headers, body):
@@ -77,7 +79,7 @@ class _HTTPClient:
 
         global DEFAULT_TIMEOUT
 
-        self._ssl_context = create_default_context()
+        self._ssl_context = self._create_ssl_context()
 
         self._retry_count = retry_count
 
@@ -89,7 +91,13 @@ class _HTTPClient:
 
         return await response.read()
 
-    def timeout(self, *, total=None, connect=None, sock_read=None, sock_connect=None):
+    def _create_ssl_context(self):
+
+        global CACERT_FILE
+
+        return ssl.create_default_context(cafile=CACERT_FILE)
+
+    def create_timeout(self, *, total=None, connect=None, sock_read=None, sock_connect=None):
         """生成超时配置对象
 
         Args:
@@ -133,7 +141,7 @@ class _HTTPClient:
 
         settings.setdefault(r'ssl', self._ssl_context)
 
-        async for times in AsyncCirculatorForSecond(max_times=self._retry_count):
+        async for times in _AsyncCirculator(max_times=self._retry_count):
 
             try:
 
@@ -481,6 +489,8 @@ class Downloader(_HTTPClient):
 
             Utils.log.error(err)
 
+            self._state = STATE.FAILURE
+
         return result
 
 
