@@ -66,7 +66,8 @@ class AsyncNTPClient(_Interface):
         self._offset = 0
 
         self._thread_pool = ThreadPool(1)
-        self._sync_task = IntervalTask(self.calibrate_offset, interval)
+
+        self._sync_task = IntervalTask.create(interval, self.calibrate_offset)
 
         self._sampling = sampling
 
