@@ -1,187 +1,115 @@
 # -*- coding: utf-8 -*-
 
-import asyncio
+import pytz
+import logging
 
-from crontab import CronTab
 from collections import OrderedDict
 
+from apscheduler.schedulers.asyncio import AsyncIOScheduler
+from apscheduler.triggers.cron import CronTrigger
+
 from hagworm.extend.interface import TaskInterface
 
 from .base import Utils, FutureWithTask
 
 
-class _BaseTask(TaskInterface):
-    """异步任务基类
+TIMEZONE = pytz.timezone(r'Asia/Shanghai')
+
+
+logging.getLogger(r'apscheduler').setLevel(logging.ERROR)
+
+
+class TaskAbstract(TaskInterface):
+    """任务基类
     """
 
-    def __init__(self, _callable):
+    def __init__(self, scheduler=None):
 
-        self._running = False
-        self._next_timeout = 0
+        global TIMEZONE
 
-        self._event_loop = None
-        self._timeout_handle = None
+        self._scheduler = AsyncIOScheduler(
+            job_defaults={
+                r'coalesce': False,
+                r'max_instances': 1,
+                r'misfire_grace_time': 30
+            },
+            timezone=TIMEZONE
+        ) if scheduler is None else scheduler
 
-        self._callable = _callable
+    @property
+    def scheduler(self):
 
-    def start(self, promptly=False, *, event_loop=None):
-
-        if event_loop:
-            self._event_loop = event_loop
-        else:
-            self._event_loop = asyncio.get_event_loop()
-
-        self._running = True
-
-        if promptly:
-            self._timeout_handle = Utils.call_soon(self._run)
-        else:
-            self._schedule_next()
-
-    def stop(self):
-
-        self._running = False
-
-        if self._timeout_handle is not None:
-            self._timeout_handle.cancel()
-            self._timeout_handle = None
+        return self._scheduler
 
     def is_running(self):
 
-        return self._running
+        return self._scheduler.running
 
-    async def _run(self):
+    def start(self):
 
-        if not self._running:
-            return
+        return self._scheduler.start()
 
-        try:
+    def stop(self):
 
-            await Utils.awaitable_wrapper(
-                self._callable()
-            )
+        return self._scheduler.shutdown()
 
-        except Exception as err:
+    def add_job(self):
 
-            Utils.log.error(err)
+        raise NotImplementedError()
 
-        finally:
+    def remove_job(self, job_id):
 
-            self._schedule_next()
+        return self._scheduler.remove_job(job_id)
 
-    def _schedule_next(self):
+    def remove_all_jobs(self):
 
-        if self._running:
-            self._timeout_handle = Utils.call_at(self._update_next(), self._run)
-
-    def _update_next(self):
-
-        self._next_timeout = self._event_loop.time()
-
-        return self._next_timeout
+        return self._scheduler.remove_all_jobs()
 
 
-class LoopTask(_BaseTask):
-    """循环任务类
-    """
-
-    @classmethod
-    def create(cls, limit_time, promptly, _callable, *args, **kwargs):
-
-        if args or kwargs:
-            _callable = Utils.func_partial(_callable, *args, **kwargs)
-
-        task = cls(_callable, limit_time)
-
-        task.start(promptly)
-
-        return task
-
-    def __init__(self, _callable, limit_time):
-
-        super().__init__(_callable)
-
-        self._limit_time = limit_time
-
-    def _update_next(self):
-
-        now_time = self._event_loop.time()
-        next_timeout = self._next_timeout + self._limit_time
-
-        if next_timeout < now_time:
-            self._next_timeout = now_time
-        else:
-            self._next_timeout = next_timeout
-
-        return self._next_timeout
-
-
-class IntervalTask(_BaseTask):
+class IntervalTask(TaskAbstract):
     """间隔任务类
     """
 
     @classmethod
-    def create(cls, interval, promptly, _callable, *args, **kwargs):
+    def create(cls, interval, func, *args, **kwargs):
+
+        inst = cls()
+
+        inst.add_job(interval, func, *args, **kwargs)
+
+        return inst
+
+    def add_job(self, interval, func, *args, **kwargs):
 
         if args or kwargs:
-            _callable = Utils.func_partial(_callable, *args, **kwargs)
+            _func = Utils.func_partial(func, *args, **kwargs)
+        else:
+            _func = func
 
-        task = cls(_callable, interval)
-
-        task.start(promptly)
-
-        return task
-
-    def __init__(self, _callable, interval):
-
-        super().__init__(_callable)
-
-        self._interval = interval
-
-    def _update_next(self):
-
-        self._next_timeout = self._event_loop.time() + self._interval
-
-        return self._next_timeout
+        return self._scheduler.add_job(_func, r'interval', seconds=interval)
 
 
-class CronTask(_BaseTask, CronTab):
+class CronTask(TaskAbstract):
     """定时任务类
     """
 
     @classmethod
-    def create(cls, crontab, promptly, _callable, *args, **kwargs):
+    def create(cls, crontab, func, *args, **kwargs):
+
+        inst = cls()
+
+        inst.add_job(crontab, func, *args, **kwargs)
+
+        return inst
+
+    def add_job(self, crontab, func, *args, **kwargs):
 
         if args or kwargs:
-            _callable = Utils.func_partial(_callable, *args, **kwargs)
+            _func = Utils.func_partial(func, *args, **kwargs)
+        else:
+            _func = func
 
-        task = cls(_callable, crontab)
-
-        task.start(promptly)
-
-        return task
-
-    def __init__(self, _callable, crontab, default_now=None, default_utc=None):
-
-        _BaseTask.__init__(self, _callable)
-        CronTab.__init__(self, crontab)
-
-        self._default_now = default_now
-        self._default_utc = default_utc
-
-    def _update_next(self):
-
-        params = {}
-
-        if self._default_now is not None:
-            params[r'now'] = self._default_now
-
-        if self._default_utc is not None:
-            params[r'default_utc'] = self._default_utc
-
-        self._next_timeout = self._event_loop.time() + self.next(**params)
-
-        return self._next_timeout
+        return self._scheduler.add_job(_func, CronTrigger.from_crontab(crontab, TIMEZONE))
 
 
 class RateLimiter:
