@@ -2,10 +2,10 @@
 
 from .base import Utils, AsyncContextManager
 
-from hagworm.extend.transaction import TransactionInterface
+from hagworm.extend.transaction import TransactionAbstract
 
 
-class Transaction(TransactionInterface, AsyncContextManager):
+class Transaction(TransactionAbstract, AsyncContextManager):
     """事务对象
 
     使用异步上下文实现的一个事务对象，可以设置commit和rollback回调
