@@ -2,7 +2,6 @@
 
 import zmq
 
-from concurrent.futures import CancelledError
 from zmq.asyncio import Context
 
 from hagworm.extend.base import ContextManager
@@ -17,7 +16,9 @@ class _SocketBase(ContextManager):
         self._name = name if name else Utils.uuid1()[:8]
 
         self._context = Context.instance()
-        self._socket = self._context.socket(socket_type)
+
+        self._socket = None
+        self._socket_type = socket_type
 
         self._address = address
         self._bind_mode = bind_mode
@@ -30,75 +31,92 @@ class _SocketBase(ContextManager):
 
         self.close()
 
-    def open(self):
+    @property
+    def socket(self):
+
+        return self._socket
+
+    def open(self, hwm=None):
+
+        self._socket = self._context.socket(self._socket_type)
 
         if self._bind_mode:
             self._socket.bind(self._address)
         else:
             self._socket.connect(self._address)
 
+        if hwm is not None:
+            self._socket.set_hwm(hwm)
+
     def close(self):
 
         if not self._socket.closed:
             self._socket.close()
+            self._socket = None
 
-    def set_hwm(self, val):
+    async def send(self, data, noblock=False):
 
-        self._socket.set_hwm(val)
+        result = False
+
+        try:
+
+            if noblock is True:
+                await self._socket.send_pyobj(data, zmq.NOBLOCK)
+            else:
+                await self._socket.send_pyobj(data)
+
+        except zmq.error.Again as _:
+            pass
+
+        else:
+            result = True
+
+        return result
 
 
-class Subscriber(_SocketBase):
+    async def recv(self, noblock=False):
+
+        result = None
+
+        try:
+
+            if noblock is True:
+                result = await self._socket.recv_pyobj(zmq.NOBLOCK)
+            else:
+                result = await self._socket.recv_pyobj()
+
+        except zmq.error.Again as _:
+            pass
+
+        return result
+
+
+##################################################
+# 订阅模式
+
+class Subscribe(_SocketBase):
 
     def __init__(self, address, bind_mode=False, *, name=None, topic=r''):
 
         super().__init__(name, zmq.SUB, address, bind_mode)
 
-        self._msg_listen_task = None
+        self._msg_topic = topic
 
-        self._socket.setsockopt_string(zmq.SUBSCRIBE, topic)
+    def open(self, hwm=None):
 
-    async def _message_listener(self):
+        super().open(hwm)
 
-        while not self._socket.closed:
-            try:
-                await self._message_handler(
-                    await self._socket.recv_pyobj()
-                )
-            except CancelledError as _:
-                pass
-            except Exception as err:
-                Utils.log.error(err)
-
-    async def _message_handler(self, data):
-
-        raise NotImplementedError()
-
-    def open(self):
-
-        super().open()
-
-        self._msg_listen_task = Utils.create_task(self._message_listener())
-
-    def close(self):
-
-        super().close()
-
-        if self._msg_listen_task is not None:
-            self._msg_listen_task.cancel()
+        self._socket.setsockopt_string(zmq.SUBSCRIBE, self._msg_topic)
 
 
-class Publisher(_SocketBase):
+class Publish(_SocketBase):
 
     def __init__(self, address, bind_mode=False, *, name=None):
 
         super().__init__(name, zmq.PUB, address, bind_mode)
 
-    async def send(self, data):
 
-        await self._socket.send_pyobj(data)
-
-
-class PublisherWithBuffer(_SocketBase, QueueBuffer):
+class PublishWithBuffer(_SocketBase, QueueBuffer):
 
     def __init__(self, address, bind_mode=False, *, name=None, buffer_maxsize=0xffff, buffer_timeout=1):
 
@@ -115,3 +133,37 @@ class PublisherWithBuffer(_SocketBase, QueueBuffer):
             if len(self._data_list) == 0:
                 super().close()
                 break
+
+##################################################
+# 请求模式
+
+
+class Request(_SocketBase):
+
+    def __init__(self, address, *, name=None):
+
+        super().__init__(name, zmq.REQ, address, False)
+
+
+class Reply(_SocketBase):
+
+    def __init__(self, address, *, name=None):
+
+        super().__init__(name, zmq.REP, address, True)
+
+##################################################
+# 推拉模式
+
+
+class Push(_SocketBase):
+
+    def __init__(self, address, bind_mode=False, *, name=None):
+
+        super().__init__(name, zmq.PUSH, address, bind_mode)
+
+
+class Pull(_SocketBase):
+
+    def __init__(self, address, bind_mode=False, *, name=None):
+
+        super().__init__(name, zmq.PULL, address, bind_mode)
