@@ -21,9 +21,10 @@ import pickle
 import psutil
 import functools
 import binascii
-import json
+import ujson
 import zlib
 import socket
+import struct
 import unicodedata
 import calendar
 import jwt
@@ -35,6 +36,7 @@ import xml.dom.minidom
 from datetime import datetime, timedelta
 from contextlib import contextmanager, closing
 from collections import Iterable, OrderedDict
+from cachetools import cached, TTLCache
 from zipfile import ZipFile, ZIP_DEFLATED
 
 from stdnum import luhn
@@ -42,32 +44,6 @@ from stdnum import luhn
 from .error import BaseError
 
 
-def fork_processes(number, guardian=None):
-
-    pids = set()
-
-    for num in range(max(number, 2)):
-
-        pid = os.fork()
-
-        if pid == 0:
-            return num
-        else:
-            pids.add(pid)
-
-    if guardian is None:
-
-        while pids:
-            pid, _ = os.wait()
-            pids.remove(pid)
-
-    else:
-
-        guardian(pids)
-
-    sys.exit(0)
-
-
 class Utils:
     """基础工具类
 
@@ -95,11 +71,16 @@ class Utils:
 
     deepcopy = staticmethod(copy.deepcopy)
 
+    func_wraps = staticmethod(functools.wraps)
     func_partial = staticmethod(functools.partial)
 
     randint = staticmethod(random.randint)
     randstr = staticmethod(random.sample)
 
+    getenv = staticmethod(os.getenv)
+    getpid = staticmethod(os.getpid)
+    getppid = staticmethod(os.getppid)
+
     @classmethod
     def environment(cls):
 
@@ -142,24 +123,24 @@ class Utils:
     @classmethod
     def json_encode(cls, val, **kwargs):
 
-        return json.dumps(val, **kwargs).replace(r'</', r'<\\/')
+        return ujson.dumps(val, **kwargs)
 
     @classmethod
     def json_decode(cls, val, **kwargs):
 
-        return json.loads(cls.basestring(val), **kwargs)
+        return ujson.loads(cls.basestring(val), **kwargs)
 
     @classmethod
     def today(cls, origin=False):
 
-        result = datetime.today()
+        result = datetime.now()
 
         return result.replace(hour=0, minute=0, second=0, microsecond=0) if origin else result
 
     @classmethod
     def yesterday(cls, origin=False):
 
-        result = datetime.today() - timedelta(days=1)
+        result = datetime.now() - timedelta(days=1)
 
         return result.replace(hour=0, minute=0, second=0, microsecond=0) if origin else result
 
@@ -354,6 +335,17 @@ class Utils:
 
         return cls.random.choice(iterable)
 
+    @classmethod
+    def urandom_seed(cls):
+
+        seed_num = None
+
+        with open(r'/dev/urandom', r'rb') as f:
+            seed_num = struct.unpack(f'!I', f.read(4))[0]
+            random.seed(seed_num)
+
+        return seed_num
+
     @classmethod
     def get_host_ip(cls):
 
@@ -840,6 +832,7 @@ class Utils:
             _zf.extractall(file_paths)
 
     @classmethod
+    @cached(cache=TTLCache(maxsize=0xf, ttl=1))
     def get_cpu_percent(cls):
 
         return psutil.cpu_percent()
@@ -903,39 +896,6 @@ def catch_error():
         Utils.log.exception(err)
 
 
-class HeartbeatChecker:
-
-    def __init__(self, name=None, timeout=60):
-
-        self._name = name if name else Utils.uuid1()
-        self._timeout = timeout
-
-        self._heartbeat_time = 0
-
-    def __bool__(self):
-
-        return Utils.timestamp() < (self._heartbeat_time + self._timeout)
-
-    @property
-    def name(self):
-
-        return self._name
-
-    @property
-    def timeout(self):
-
-        return self._timeout
-
-    @property
-    def heartbeat_time(self):
-
-        return self._heartbeat_time
-
-    def refresh(self):
-
-        self._heartbeat_time = Utils.timestamp()
-
-
 class ContextManager:
     """上下文资源管理器
 
@@ -943,6 +903,10 @@ class ContextManager:
 
     """
 
+    def __del__(self):
+
+        self._context_release()
+
     def __enter__(self):
 
         self._context_initialize()
