@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
 import re
-import json
 import struct
 import threading
 
@@ -147,8 +146,8 @@ class Const(OrderedDict):
         return val in self.values()
 
 
-class ByteArray(BytesIO):
-    """扩展的BytesIO类
+class ByteArrayAbstract:
+    """ByteArray抽象类
     """
 
     NETWORK = r'!'
@@ -157,9 +156,7 @@ class ByteArray(BytesIO):
     LITTLE_ENDIAN = r'<'
     BIG_ENDIAN = r'>'
 
-    def __init__(self, *args, **kwargs):
-
-        super().__init__(*args, **kwargs)
+    def __init__(self):
 
         self._endian = self.NETWORK
 
@@ -171,6 +168,14 @@ class ByteArray(BytesIO):
 
         self._endian = val
 
+    def read(self, size):
+
+        raise NotImplementedError()
+
+    def write(self, buffer):
+
+        raise NotImplementedError()
+
     def read_pad_byte(self, _len):
 
         struct.unpack(f'{self._endian}{_len}x', self.read(_len))
@@ -245,7 +250,7 @@ class ByteArray(BytesIO):
 
     def read_long(self):
 
-        return struct.unpack(f'{self._endian}l', self.read(8))[0]
+        return struct.unpack(f'{self._endian}l', self.read(4))[0]
 
     def write_long(self, val):
 
@@ -253,7 +258,7 @@ class ByteArray(BytesIO):
 
     def read_unsigned_long(self):
 
-        return struct.unpack(f'{self._endian}L', self.read(8))[0]
+        return struct.unpack(f'{self._endian}L', self.read(4))[0]
 
     def write_unsigned_long(self, val):
 
@@ -332,6 +337,22 @@ class ByteArray(BytesIO):
         self.write(struct.pack(f'{self._endian}{len(val)}P', val))
 
 
+class ByteArray(BytesIO, ByteArrayAbstract):
+    """扩展的BytesIO类
+    """
+
+    NETWORK = r'!'
+    NATIVE = r'='
+    NATIVE_ALIGNMENT = r'@'
+    LITTLE_ENDIAN = r'<'
+    BIG_ENDIAN = r'>'
+
+    def __init__(self, initial_bytes=None):
+
+        BytesIO.__init__(self, initial_bytes)
+        ByteArrayAbstract.__init__(self)
+
+
 class ConfigParser(RawConfigParser):
     """配置解析类
     """
@@ -346,7 +367,7 @@ class ConfigParser(RawConfigParser):
 
         val = self.get(section, option, **kwargs)
 
-        result = json.loads(val)
+        result = Utils.json_encode(val)
 
         return result
 
@@ -368,13 +389,13 @@ class ConfigParser(RawConfigParser):
 
         val = self.get(section, option, **kwargs)
 
-        return Utils.split_str(val, sep)
+        return tuple(Utils.split_str(val, sep))
 
     def get_split_int(self, section, option, sep=r',', **kwargs):
 
         val = self.get(section, option, **kwargs)
 
-        return Utils.split_int(val, sep)
+        return tuple(Utils.split_int(val, sep))
 
     def split_float(self, val, sep=r','):
 
