@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 
 import signal
+import socket
 import asyncio
-import logging
 
 import jinja2
 
 from tornado_jinja2 import Jinja2Loader
 
+from tornado import version as tornado_version
 from tornado.web import Application
 from tornado.options import options
 from tornado.process import cpu_count, fork_processes
@@ -15,29 +16,15 @@ from tornado.netutil import bind_sockets
 from tornado.httpserver import HTTPServer
 from tornado.platform.asyncio import AsyncIOMainLoop
 
-from hagworm import package_slogan
-from hagworm import __version__ as package_version
+from hagworm import hagworm_slogan
+from hagworm import __version__ as hagworm_version
 from hagworm.extend.base import Utils
+from hagworm.extend.logging import DEFAULT_LOG_FILE_ROTATOR, init_logger
 from hagworm.extend.interface import TaskInterface
 from hagworm.extend.asyncio.base import install_uvloop
 from hagworm.frame.tornado.web import LogRequestMixin
 
 
-class _InterceptHandler(logging.Handler):
-    """日志监听器
-    """
-
-    def emit(self, record):
-
-        Utils.log.opt(
-            depth=6,
-            exception=record.exc_info
-        ).log(
-            record.levelname,
-            record.getMessage()
-        )
-
-
 class _LauncherBase(TaskInterface):
     """启动器基类
     """
@@ -47,7 +34,9 @@ class _LauncherBase(TaskInterface):
         self._debug = kwargs.get(r'debug', False)
 
         self._process_num = kwargs.get(r'process_num', 1)
-        self._async_initialize = kwargs.get(r'async_initialize', None)
+
+        self._on_startup = kwargs.get(r'on_startup', None)
+        self._on_shutdown = kwargs.get(r'on_shutdown', None)
 
         self._background_service = kwargs.get(r'background_service', None)
         self._background_process = kwargs.get(r'background_process', None)
@@ -69,70 +58,45 @@ class _LauncherBase(TaskInterface):
         else:
             raise TypeError(r'Background Process Dot Implemented Task Interface')
 
-        self._init_logger(
+        init_logger(
             kwargs.get(r'log_level', r'info').upper(),
             kwargs.get(r'log_handler', None),
             kwargs.get(r'log_file_path', None),
-            kwargs.get(r'log_file_num_backups', 7)
+            kwargs.get(r'log_file_rotation', DEFAULT_LOG_FILE_ROTATOR),
+            kwargs.get(r'log_file_retention', 0xff),
+            self._debug
         )
 
         environment = Utils.environment()
 
         Utils.log.info(
-            f'{package_slogan}'
-            f'hagworm {package_version}\n'
+            f'{hagworm_slogan}'
+            f'hagworm {hagworm_version}\n'
+            f'tornado {tornado_version}\n'
             f'python {environment["python"]}\n'
             f'system {" ".join(environment["system"])}'
         )
 
         install_uvloop()
 
+        self._sockets = None
         self._event_loop = None
 
-    def _init_logger(self, log_level, log_handler=None, log_file_path=None, log_file_num_backups=7):
+    def set_socket_buf(self, *, snd_buf=0, rcv_buf=0):
 
-        if log_handler or log_file_path:
+        for _socket in self._sockets:
 
-            Utils.log.remove()
+            if snd_buf > 0:
+                _socket.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, snd_buf)
 
-            if log_handler:
-
-                Utils.log.add(
-                    log_handler,
-                    level=log_level,
-                    enqueue=True,
-                    backtrace=self._debug
-                )
-
-            if log_file_path:
-
-                log_file_path = Utils.path.join(
-                    log_file_path,
-                    r'runtime_{time}.log'
-                )
-
-                Utils.log.add(
-                    log_file_path,
-                    level=log_level,
-                    enqueue=True,
-                    backtrace=self._debug,
-                    rotation=r'00:00',
-                    retention=log_file_num_backups
-                )
-
-        else:
-
-            Utils.log.level(log_level)
-
-        logging.getLogger(None).addHandler(_InterceptHandler())
-
-    @property
-    def process_id(self):
-
-        return self._process_id
+            if rcv_buf > 0:
+                _socket.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, rcv_buf)
 
     def start(self):
 
+        if self._on_startup:
+            self._event_loop.run_until_complete(self._on_startup())
+
         if self._background_service is not None:
             self._background_service.start()
             Utils.log.success(f'Background service no.{self._process_id} running...')
@@ -147,7 +111,10 @@ class _LauncherBase(TaskInterface):
 
         self._event_loop.run_forever()
 
-    def stop(self, code=0, frame=None):
+        if self._on_shutdown is not None:
+            self._event_loop.run_until_complete(self._on_shutdown())
+
+    def stop(self, code=0):
 
         if self._background_service is not None:
             self._background_service.stop()
@@ -217,10 +184,7 @@ class Launcher(_LauncherBase):
         self._event_loop = asyncio.get_event_loop()
         self._event_loop.set_debug(self._settings[r'debug'])
 
+        self._event_loop.add_signal_handler(signal.SIGINT, self.stop)
+        self._event_loop.add_signal_handler(signal.SIGTERM, self.stop)
+
         self._server = HTTPServer(_Application(**self._settings))
-
-        signal.signal(signal.SIGINT, self.stop)
-        signal.signal(signal.SIGTERM, self.stop)
-
-        if self._async_initialize:
-            self._event_loop.run_until_complete(self._async_initialize())
