@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 
 import os
-import json
-import functools
 import aiohttp
 
 from aiohttp.web_exceptions import HTTPBadGateway
@@ -10,6 +8,7 @@ from aiohttp.web_exceptions import HTTPBadGateway
 from tornado.web import RequestHandler
 from tornado.websocket import WebSocketHandler
 
+from hagworm import hagworm_label
 from hagworm.extend.struct import Result
 from hagworm.extend.asyncio.base import Utils
 from hagworm.extend.asyncio.net import DownloadBuffer, HTTPClientPool
@@ -17,6 +16,8 @@ from hagworm.extend.asyncio.net import DownloadBuffer, HTTPClientPool
 from wtforms_tornado import Form
 
 
+ACCESS_CONTROL_ALLOW_ORIGIN = r'*'
+
 PROXY_IGNORE_HEADERS = (r'CONTENT-ENCODING', r'TRANSFER-ENCODING',)
 
 
@@ -24,7 +25,7 @@ def json_wraps(func):
     """json装饰器
     """
 
-    @functools.wraps(func)
+    @Utils.func_wraps(func)
     async def _wrapper(handler, *args, **kwargs):
 
         resp = await Utils.awaitable_wrapper(
@@ -49,7 +50,7 @@ class HttpBasicAuth:
 
     def __call__(self, func):
 
-        @functools.wraps(func)
+        @Utils.func_wraps(func)
         def _wrapper(handler, *args, **kwargs):
 
             auth_header = handler.get_header(r'Authorization')
@@ -82,7 +83,7 @@ class FormInjection:
     """表单注入器
     """
 
-    def __init__(self, form_cls=None, err_code: int = -1):
+    def __init__(self, form_cls, err_code: int = -1):
 
         if not issubclass(form_cls, Form):
             raise TypeError(r'Dot Implemented Form Interface')
@@ -92,7 +93,7 @@ class FormInjection:
 
     def __call__(self, func):
 
-        @functools.wraps(func)
+        @Utils.func_wraps(func)
         async def _wrapper(handler: RequestBaseHandler, *args, **kwargs):
 
             form = self._form_cls(handler.request.arguments)
@@ -120,7 +121,7 @@ class DebugHeader:
 
     def __call__(self, func):
 
-        @functools.wraps(func)
+        @Utils.func_wraps(func)
         async def _wrapper(handler: RequestBaseHandler, *args, **kwargs):
 
             if self._is_debug() is True:
@@ -157,12 +158,12 @@ class LogRequestMixin:
 
         Utils.log.info(
             '\n---------- request arguments ----------\n' +
-            json.dumps(
+            Utils.json_encode(
                 {
                     key: [Utils.basestring(val) for val in items]
                     for key, items in self.request.arguments.items()
                 },
-                ensure_ascii=False, indent=4
+                escape_forward_slashes=False, ensure_ascii=False, indent=4
             )
         )
 
@@ -231,7 +232,7 @@ class _BaseHandlerMixin(Utils):
     @property
     def client_ip(self):
 
-        return self.get_header(r'X-Real-IP', self.request.remote_ip)
+        return self.get_header(r'X-Read-IP', self.request.remote_ip)
 
     @property
     def content_type(self):
@@ -304,20 +305,21 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
 
     def set_default_headers(self):
 
+        global ACCESS_CONTROL_ALLOW_ORIGIN
+
         self.set_header(r'Cache-Control', r'no-cache')
+        self.set_header(r'Server', hagworm_label)
 
-        self.set_header(r'X-Timestamp', self.timestamp())
-
-        payload = self.get_header(r'X-Payload')
+        payload = self.get_header(r'X-Client-Payload')
 
         if payload:
-            self.set_header(r'X-Payload', payload)
+            self.set_header(r'X-Client-Payload', payload)
 
         origin = self.get_header(r'Origin')
 
         if origin:
 
-            self.set_header(r'Access-Control-Allow-Origin', r'*')
+            self.set_header(r'Access-Control-Allow-Origin', ACCESS_CONTROL_ALLOW_ORIGIN)
 
             method = self.get_header(r'Access-Control-Request-Method')
             if method:
